#!/usr/bin/env bash

#####################################################
################### Test dataset  ###################
#####################################################

source bash/dataset_utils.sh
source bash/provenance_utils.sh

### -------------------------------------------- ###
## --------------- Define variables ------------- ##
### -------------------------------------------- ###

dataset_name="utils_test_data"
description="Randomly generated dataset to facilitate testing of utils functions"
title="Utils test dataset"
keywords=("utils_test")

data_script="test/test_helper/generate_test_data_files.sh"

create_dataset -n $dataset_name -d $description -t $title -k $keywords
mkdir -p test/data/${dataset_name}

### -------------------------------------------- ###
## ---- Serialise project's knowledge graph ----- ##
### -------------------------------------------- ###

renku graph generate -f
renku save

### -------------------------------------------- ###
## ---------- Data generation workflow ---------- ##
### -------------------------------------------- ###

workflow_exists=(`list_plan_inputs .renku/provenance.json ${data_script}`)

if [ -z "$workflow_exists" ]
then
    renku run --input ${data_script} -- $data_script test/data/${dataset_name}/test_file.json
fi

### -------------------------------------------- ###
## ----------- Update workflow outputs ---------- ##
### -------------------------------------------- ###

renku update --with-siblings test/data/${dataset_name}/*
renku save


### -------------------------------------------- ###
## ------------ Add files to dataset ------------ ##
### -------------------------------------------- ###

data_files="test/data/${dataset_name}/*"
add_files_to_dataset_by_name ${dataset_name} ${data_files[@]}
renku save

